@@ -403,6 +403,7 @@
 \\medium
 \\maxima
 \\markuplist
+\\markupMap
 \\markup
 \\markletter
 \\markalphabet
@@ -865,6 +866,7 @@ Parenthesis_engraver
 Paper_column_engraver
 Output_property_engraver
 Ottava_spanner_engraver
+OneStaff
 NullVoice
 Note_spacing_engraver
 Note_performer
